@@ -6,11 +6,9 @@ from envparse import env
 
 from .handlers.base import Handler
 
-env.read_envfile()
-
 BOT_TOKEN = env('BOT_TOKEN')
 MONGO_DB = env('MONGO_DB')
-MONGO_HOST = env('MONGO_HOST')
+MONGO_HOST = env('MONGO_HOST', 'localhost')
 
 logger = logging.getLogger('bot')
 mongoengine.connect(MONGO_DB, host=MONGO_HOST)
